==> apache-qpid-broker-j-7.1.12-src.tar.gz: apache-qpid-broker-j-7.1.12-src/systests/protocol-tests-amqp-1-0/src/main/java/org/apache/qpid/tests/protocol/v1_0/InteractionTransactionalState.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.tests.protocol.v1_0;

import org.apache.qpid.server.protocol.v1_0.type.Binary;
import org.apache.qpid.server.protocol.v1_0.type.UnsignedInteger;

public class InteractionTransactionalState
{
    private final UnsignedInteger _handle;
    private Binary _lastTransactionId;

    public InteractionTransactionalState(final UnsignedInteger handle)
    {
        _handle = handle;
    }

    public UnsignedInteger getHandle()
    {
        return _handle;
    }

    public void setLastTransactionId(final Binary lastTransactionId)
    {
        _lastTransactionId = lastTransactionId;
    }

    public Binary getCurrentTransactionId()
    {
        return _lastTransactionId;
    }
}

==> apache-qpid-broker-j-10.0.0-src.tar.gz: apache-qpid-broker-j-10.0.0-src/systests/protocol-tests-amqp-1-0/src/main/java/org/apache/qpid/tests/protocol/v1_0/InteractionTransactionalState.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.tests.protocol.v1_0;

import org.apache.qpid.server.protocol.v1_0.type.Binary;
import org.apache.qpid.server.protocol.v1_0.type.DeliveryState;
import org.apache.qpid.server.protocol.v1_0.type.UnsignedInteger;

public class InteractionTransactionalState
{
    private final UnsignedInteger _handle;
    private Binary _lastTransactionId;
    private DeliveryState _deliveryState;

    public InteractionTransactionalState(final UnsignedInteger handle)
    {
        _handle = handle;
    }

    public UnsignedInteger getHandle()
    {
        return _handle;
    }

    public void setLastTransactionId(final Binary lastTransactionId)
    {
        _lastTransactionId = lastTransactionId;
    }

    public Binary getCurrentTransactionId()
    {
        return _lastTransactionId;
    }

    public DeliveryState getDeliveryState()
    {
        return _deliveryState;
    }

    public void setDeliveryState(final DeliveryState deliveryState)
    {
        _deliveryState = deliveryState;
    }
}
